pub struct Stream(/* private fields */);Expand description
The Stream implementation associated with the platform’s dynamically dispatched
Host type.
Implementations
Sourceimpl Stream
impl Stream
Sourcepub fn as_inner(&self) -> &StreamInner
Available on Android only.
pub fn as_inner(&self) -> &StreamInner
Returns a reference to the underlying platform specific implementation of this
Stream.
Sourcepub fn as_inner_mut(&mut self) -> &mut StreamInner
Available on Android only.
pub fn as_inner_mut(&mut self) -> &mut StreamInner
Returns a mutable reference to the underlying platform specific implementation of
this Stream.
Sourcepub fn into_inner(self) -> StreamInner
Available on Android only.
pub fn into_inner(self) -> StreamInner
Returns the underlying platform specific implementation of this Stream.