DeviceDescriptionBuilder

Struct DeviceDescriptionBuilder 

pub struct DeviceDescriptionBuilder { /* private fields */ }
Builder for constructing a DeviceDescription.

This is primarily used by host implementations and custom hosts to gradually build up device descriptions with available metadata.

Implementations

Source

impl DeviceDescriptionBuilder

pub fn new(name: impl Into<String>) -> Self

Creates a new builder with the device name (required).

pub fn manufacturer(self, manufacturer: impl Into<String>) -> Self

Sets the manufacturer name.

pub fn driver(self, driver: impl Into<String>) -> Self

Sets the driver name.

pub fn device_type(self, device_type: DeviceType) -> Self

Sets the device type.

pub fn interface_type(self, interface_type: InterfaceType) -> Self

Sets the interface type.

pub fn direction(self, direction: DeviceDirection) -> Self

Sets the device direction.

pub fn address(self, address: impl Into<String>) -> Self

Sets the physical address.

pub fn extended(self, lines: Vec<String>) -> Self

Sets the description lines.

pub fn add_extended_line(self, line: impl Into<String>) -> Self

Adds a single description line.

pub fn build(self) -> DeviceDescription

Builds the DeviceDescription.